/*
** ---------------------------------------------------------------
** idp.h  -  Declaracoes do modulo que calcula Integral de Divisao
**           de Polinomios.
**
** ---------------------------------------------------------------
*/

#ifndef _IDP_H
#define _IDP_H

/*@{*/
/**
** @name Modulo que calcula integral de divisao de polinomios
**
** @date    25-Out-2005
** @author  Alexandre Lopes e Luiz F. Martha
** @version 1.0
**
** Este modulo contem uma funcao que calcula a integral 
** unidimensional de divisao de polinomios em uma faixa
** arbitraria.
**
** Revisoes:
**
*/

/*
** ---------------------------------------------------------------
** Definicoes globais utilizadas:
**
*/

/*
** ---------------------------------------------------------------
** Definicoes exportadas:
*/


/*
** ---------------------------------------------------------------
** Funcoes publicas:
**
*/

/* --------------------------------------------------------------- */
/**
 ** Esta funcao realiza a integracao da divisao de dois polinomios
 ** no intervalo [a,b].  A funcao, que e' recursiva, utiliza uma 
 ** funcao local e verifica se e' necessario subdividir o intervalo
 ** de integracao.  Em caso da diferenca entre o valor da integral
 ** calculado em todo o trecho ser diferente, a menos de uma 
 ** tolerancia, da soma dos valores calculados nas duas metades
 ** do trecho, a funcao calcula recursivamente a integral em cada
 ** metade do trecho.
 ** A funcao utiliza integracao numerica de Gauss com quatro
 ** pontos de integracao em cada trecho.
 ** 
 ** @param coefPoliNumerador   - coeficientes do polinomio do numerador
 **                              (primeira posicao e' o grau)
 ** @param coefPoliDenominador - coeficientes do polinomio do denominador
 **                              (primeira posicao e' o grau)
 ** @param a                   - limite inferior de integracao
 ** @param b                   - limite superior de integracao
 **
 ** @return
 ** Resultado da integracao
*/
double idpIntegraDivPoli( double *coefPoliNumerador, 
                          double *coefPoliDenominador, 
                          double a, double b );

/*@}*/

#endif
